@@ -18,7 +18,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author:  Roberto Majadas <roberto.majadas@hispalinux.es>
+ * Author:  Roberto Majadas <roberto.majadas@openshine.com>
  */
 
 #include "../nautilus-sendto-plugin.h"
@@ -220,6 +220,7 @@ gboolean destroy (NstPlugin *plugin){
 static 
 NstPluginInfo plugin_info = {
 	"im",
+	"gaim",
 	N_("Instant Message (Gaim)"),
 	FALSE,
 	init,
